@@ -16,6 +16,7 @@ from ._job import job_show
 from ._project import project_add_dataset
 from ._project import project_create
 from ._project import project_delete
+from ._project import project_edit
 from ._project import project_list
 from ._project import project_show
 from ._task import task_collect_pip
@@ -56,6 +57,8 @@ async def project(
         iface = await project_show(client, **kwargs)
     elif subcmd == "list":
         iface = await project_list(client, **kwargs)
+    elif subcmd == "edit":
+        iface = await project_edit(client, **kwargs)
     elif subcmd == "add-dataset":
         iface = await project_add_dataset(
             client,
@@ -85,7 +88,6 @@ async def dataset(
             project_id=kwargs.pop("project_id"),
             dataset_id=kwargs.pop("dataset_id"),
             path=kwargs.pop("path"),
-            glob_pattern=kwargs.pop("glob_pattern"),
             **kwargs,
         )
     elif subcmd == "rm-resource":
@@ -100,13 +102,11 @@ async def dataset(
     elif subcmd == "edit":
         project_id = int(kwargs.pop("project_id"))
         dataset_id = int(kwargs.pop("dataset_id"))
-
-        dataset_update_dict = kwargs
         iface = await dataset_edit(
             client,
             project_id=project_id,
             dataset_id=dataset_id,
-            dataset_update_dict=dataset_update_dict,
+            **kwargs,
         )
     elif subcmd == "delete":
         iface = await dataset_delete(client, **kwargs)
