@@ -1,6 +1,7 @@
 import json
 import logging
 from typing import Optional
+from typing import Union
 
 from rich.table import Table
 
@@ -9,6 +10,7 @@ from ..common.schemas import DatasetCreate
 from ..common.schemas import DatasetRead
 from ..common.schemas import ProjectCreate
 from ..common.schemas import ProjectRead
+from ..common.schemas import ProjectUpdate
 from ..config import settings
 from ..interface import BaseInterface
 from ..interface import PrintInterface
@@ -25,13 +27,16 @@ async def project_create(
     batch: bool = False,
     **kwargs,
 ) -> BaseInterface:
-    project = ProjectCreate(
-        name=name, project_dir=path, default_dataset_name=dataset
-    )
+    # Prepare a ProjectCreate request body
+    project_dict = dict(name=name, project_dir=path)
+    if dataset:
+        project_dict["default_dataset_name"] = dataset
+    project = ProjectCreate(**project_dict)
     logging.info(project)
+    # Send API request
     res = await client.post(
         f"{settings.BASE_URL}/project/",
-        json=project.dict(),
+        json=project.dict(exclude_unset=True),
     )
     project = check_response(res, expected_status_code=201, coerce=ProjectRead)
     if batch:
@@ -106,13 +111,14 @@ async def project_add_dataset(
     else:
         meta = json.loads(metadata_filename)
 
-    dataset = DatasetCreate(
-        name=dataset_name, project_id=project_id, type=type, meta=meta
-    )
+    dataset_dict = dict(name=dataset_name, meta=meta)
+    if type:
+        dataset_dict["type"] = type
+    dataset = DatasetCreate(**dataset_dict)
 
     res = await client.post(
         f"{settings.BASE_URL}/project/{project_id}/",
-        json=dataset.dict(),
+        json=dataset.dict(exclude_unset=True),
     )
     new_dataset = check_response(
         res, expected_status_code=201, coerce=DatasetRead
@@ -132,3 +138,37 @@ async def project_delete(
     )
     check_response(res, expected_status_code=204)
     return PrintInterface(retcode=0, data="")
+
+
+async def project_edit(
+    client: AuthClient,
+    project_id: int,
+    new_name: Optional[str] = None,
+    new_project_dir: Optional[str] = None,
+    make_read_only: bool = False,
+    remove_read_only: bool = False,
+    **kwargs,
+) -> Union[RichJsonInterface, PrintInterface]:
+    update = {}
+    if new_name:
+        update["name"] = new_name
+    if new_project_dir:
+        update["project_dir"] = new_project_dir
+    if make_read_only:
+        update["read_only"] = True
+    if remove_read_only:
+        update["read_only"] = False
+
+    project_update = ProjectUpdate(**update)  # validation
+    payload = project_update.dict(exclude_unset=True)
+
+    if not payload:
+        return PrintInterface(retcode=1, data="Nothing to update")
+
+    res = await client.patch(
+        f"{settings.BASE_URL}/project/{project_id}", json=payload
+    )
+    new_project = check_response(
+        res, expected_status_code=200, coerce=ProjectRead
+    )
+    return RichJsonInterface(retcode=0, data=new_project.dict())
