@@ -5,6 +5,7 @@ from typing import Optional
 
 from sqlmodel import SQLModel
 
+
 __all__ = (
     "_StateBase",
     "StateRead",
@@ -20,13 +21,10 @@ class _StateBase(SQLModel):
         data: Content of the state
         timestamp: Time stamp of the state
     """
-    id: Optional[int]
+
     data: Dict[str, Any]
     timestamp: datetime
 
-    class Config:
-        arbitrary_types_allowed = True
-
     def sanitised_dict(self):
         """
         Return `self.dict()` after casting `self.timestamp` to a string
@@ -37,4 +35,4 @@ class _StateBase(SQLModel):
 
 
 class StateRead(_StateBase):
-    pass
+    id: Optional[int]
