@@ -17,7 +17,8 @@ import argparse as ap
 
 
 parser_main = ap.ArgumentParser(
-    description="Command-line interface for Fractal Client"
+    description="Command-line interface for Fractal Client",
+    allow_abbrev=False,
 )
 
 parser_main.add_argument(
@@ -50,7 +51,9 @@ subparsers_main = parser_main.add_subparsers(title="Commands:", dest="cmd")
 
 # PROJECT GROUP
 project_parser = subparsers_main.add_parser(
-    "project", description="Project commands"
+    "project",
+    description="Project commands",
+    allow_abbrev=False,
 )
 project_subparsers = project_parser.add_subparsers(
     title="Valid subcommands:", dest="subcmd", required=True
@@ -58,7 +61,9 @@ project_subparsers = project_parser.add_subparsers(
 
 # project new
 project_new_parser = project_subparsers.add_parser(
-    "new", description="Create new project"
+    "new",
+    description="Create new project",
+    allow_abbrev=False,
 )
 project_new_parser.add_argument("name", help="Name of new project", type=str)
 project_new_parser.add_argument(
@@ -79,12 +84,16 @@ project_new_parser.add_argument(
 
 # project list
 project_list_parser = project_subparsers.add_parser(
-    "list", description="List projects"
+    "list",
+    description="List projects",
+    allow_abbrev=False,
 )
 
 # project show
 project_show_parser = project_subparsers.add_parser(
-    "show", description="Show details of single project"
+    "show",
+    description="Show details of single project",
+    allow_abbrev=False,
 )
 project_show_parser.add_argument(
     "project_id", type=int, help="ID of project to show"
@@ -92,7 +101,9 @@ project_show_parser.add_argument(
 
 # project delete
 project_delete_parser = project_subparsers.add_parser(
-    "delete", description="Delete project"
+    "delete",
+    description="Delete project",
+    allow_abbrev=False,
 )
 project_delete_parser.add_argument(
     "project_id", type=int, help="ID of project to delete"
@@ -100,7 +111,9 @@ project_delete_parser.add_argument(
 
 # project add-dataset
 project_add_dataset_parser = project_subparsers.add_parser(
-    "add-dataset", description="Add dataset to project"
+    "add-dataset",
+    description="Add dataset to project",
+    allow_abbrev=False,
 )
 project_add_dataset_parser.add_argument(
     "project_id", type=int, help="ID of project to add the new dataset to"
@@ -113,10 +126,43 @@ project_add_dataset_parser.add_argument(
     help="Path to file containing dataset metadata in JSON format.",
 )
 
+# project edit
+project_edit_parser = project_subparsers.add_parser(
+    "edit",
+    description="Edit details of a single project",
+    allow_abbrev=False,
+)
+project_edit_parser.add_argument(
+    "project_id", type=int, help="ID of the project to edit"
+)
+project_edit_parser.add_argument(
+    "--new-name", help="New project name", type=str, required=False
+)
+project_edit_parser.add_argument(
+    "--new-project-dir", help="New project directory", type=str, required=False
+)
+project_edit_parser_read_only = (
+    project_edit_parser.add_mutually_exclusive_group()
+)
+project_edit_parser_read_only.add_argument(
+    "--make-read-only",
+    help="Set the read-only flag for this project",
+    action="store_true",
+    required=False,
+)
+project_edit_parser_read_only.add_argument(
+    "--remove-read-only",
+    help="Remove the read-only flag for this project",
+    action="store_true",
+    required=False,
+)
+
 
 # DATASET GROUP
 dataset_parser = subparsers_main.add_parser(
-    "dataset", description="Dataset commands"
+    "dataset",
+    description="Dataset commands",
+    allow_abbrev=False,
 )
 dataset_subparsers = dataset_parser.add_subparsers(
     title="Valid subcommands:", dest="subcmd", required=True
@@ -124,7 +170,9 @@ dataset_subparsers = dataset_parser.add_subparsers(
 
 # dataset add-resource
 dataset_add_resource_parser = dataset_subparsers.add_parser(
-    "add-resource", description="Add resource to existing dataset"
+    "add-resource",
+    description="Add resource to existing dataset",
+    allow_abbrev=False,
 )
 dataset_add_resource_parser.add_argument(
     "project_id", type=int, help="Project ID"
@@ -133,13 +181,12 @@ dataset_add_resource_parser.add_argument(
     "dataset_id", type=int, help="Dataset ID"
 )
 dataset_add_resource_parser.add_argument("path", help="Path to resource")
-dataset_add_resource_parser.add_argument(
-    "-g", "--glob-pattern", help="Glob pattern"
-)
 
 # dataset rm-resource
 dataset_rm_resource_parser = dataset_subparsers.add_parser(
-    "rm-resource", description="Remove resource to existing dataset"
+    "rm-resource",
+    description="Remove resource to existing dataset",
+    allow_abbrev=False,
 )
 dataset_rm_resource_parser.add_argument(
     "project_id", type=int, help="Project ID"
@@ -153,61 +200,84 @@ dataset_rm_resource_parser.add_argument(
 
 # dataset edit
 dataset_edit_parser = dataset_subparsers.add_parser(
-    "edit", description="Edit dataset", argument_default=ap.SUPPRESS
+    "edit",
+    description="Edit dataset",
+    argument_default=ap.SUPPRESS,
+    allow_abbrev=False,
 )
 dataset_edit_parser.add_argument("project_id", type=int, help="Project ID")
 dataset_edit_parser.add_argument("dataset_id", type=int, help="Dataset ID")
-dataset_edit_parser.add_argument("--name", help="New name of dataset")
-dataset_edit_parser.add_argument("--path", help="New path of dataset")
 dataset_edit_parser.add_argument(
-    "--metadata",
-    help=(
-        "Path to file containing dataset metadata in JSON format. "
-        "(Set to `none` to clear)"
-    ),
+    "--new-name",
+    help="New name of dataset",
+    type=str,
 )
 dataset_edit_parser.add_argument(
-    "--read-only",
-    dest="read_only",
+    "--new-type",
+    help="Dataset type",
+    type=str,
+)
+dataset_edit_parser.add_argument(
+    "--meta-file",
+    help="Path to JSON file with new metadata to replace the current ones",
+)
+dataset_edit_parser_read = dataset_edit_parser.add_mutually_exclusive_group()
+dataset_edit_parser_read.add_argument(
+    "--make-read-only",
     help="Set read-only flag of dataset",
     action="store_true",
+    required=False,
 )
-dataset_edit_parser.add_argument(
-    "--read-write",
-    dest="read_only",
-    help="Set read-only flag of dataset (0 for False, 1 for True)",
-    action="store_false",
+dataset_edit_parser_read.add_argument(
+    "--remove-read-only",
+    help="Remove read-only flag of dataset",
+    action="store_true",
+    required=False,
 )
-dataset_edit_parser.add_argument("-t", "--type", help="Dataset type")
 
 # dataset show
 dataset_show_parser = dataset_subparsers.add_parser(
-    "show", description="Show dataset", argument_default=ap.SUPPRESS
+    "show",
+    description="Show dataset",
+    argument_default=ap.SUPPRESS,
+    allow_abbrev=False,
 )
 dataset_show_parser.add_argument("project_id", type=int, help="Project ID")
 dataset_show_parser.add_argument("dataset_id", type=int, help="Dataset ID")
 
 # dataset delete
 dataset_delete_parser = dataset_subparsers.add_parser(
-    "delete", description="Delete dataset", argument_default=ap.SUPPRESS
+    "delete",
+    description="Delete dataset",
+    argument_default=ap.SUPPRESS,
+    allow_abbrev=False,
 )
 dataset_delete_parser.add_argument("project_id", type=int, help="Project ID")
 dataset_delete_parser.add_argument("dataset_id", type=int, help="Dataset ID")
 
 
 # TASK GROUP
-task_parser = subparsers_main.add_parser("task", description="Task commands")
+task_parser = subparsers_main.add_parser(
+    "task",
+    description="Task commands",
+    allow_abbrev=False,
+)
 task_subparsers = task_parser.add_subparsers(
     title="Valid subcommands:", dest="subcmd", required=True
 )
 
 # task list
-task_list_parser = task_subparsers.add_parser("list", description="List tasks")
+task_list_parser = task_subparsers.add_parser(
+    "list",
+    description="List tasks",
+    allow_abbrev=False,
+)
 
 # task collect
 task_collect_parser = task_subparsers.add_parser(
     "collect",
     description="Install and collect all tasks from a pip-installable package",
+    allow_abbrev=False,
 )
 task_collect_parser.add_argument(
     "package",
@@ -241,6 +311,7 @@ task_collect_parser.add_argument(
 task_check_collection_parser = task_subparsers.add_parser(
     "check-collection",
     description="Check status of background task collection processes",
+    allow_abbrev=False,
 )
 task_check_collection_parser.add_argument(
     "state_id",
@@ -252,10 +323,21 @@ task_check_collection_parser.add_argument(
     action="store_true",
     help="Also include task-collection logs",
 )
+task_check_collection_parser.add_argument(
+    "--do-not-separate-logs",
+    dest="do_not_separate_logs",
+    help="Show the job logs in the main output, instead of a separate field",
+    action="store_true",
+    required=False,
+)
+
 
 # task new
 task_new_parser = task_subparsers.add_parser(
-    "new", description="Create new task", argument_default=ap.SUPPRESS
+    "new",
+    description="Create new task",
+    argument_default=ap.SUPPRESS,
+    allow_abbrev=False,
 )
 task_new_parser.add_argument(
     "name", help="A human readable name for the task", type=str
@@ -289,27 +371,42 @@ task_new_parser.add_argument(
 
 # task edit
 task_edit_parser = task_subparsers.add_parser(
-    "edit", description="Edit task", argument_default=ap.SUPPRESS
+    "edit",
+    description="Edit task",
+    argument_default=ap.SUPPRESS,
+    allow_abbrev=False,
 )
 task_edit_parser.add_argument(
     "task_id_or_name", help="ID or name of task to edit", type=str
 )
 task_edit_parser.add_argument("--name", help="New task name")
+task_edit_parser.add_argument("--command", help="New task command")
 task_edit_parser.add_argument(
     "--input-type",
     help="New input type",
 )
 task_edit_parser.add_argument(
     "--output-type",
-    help="New resource type",
+    help="New output type",
 )
 task_edit_parser.add_argument(
-    "--default-args", help="Filename containing JSON encoded default arguments"
+    "--default-args-file",
+    help=(
+        "Path to JSON serialised file containing "
+        "the task default arguments dictionary"
+    ),
+)
+task_edit_parser.add_argument(
+    "--meta-file",
+    help="Path to JSON serialised file containing the task meta dictionary",
 )
 
 # task delete
 task_delete_parser = task_subparsers.add_parser(
-    "delete", description="Delete task", argument_default=ap.SUPPRESS
+    "delete",
+    description="Delete task",
+    argument_default=ap.SUPPRESS,
+    allow_abbrev=False,
 )
 task_delete_parser.add_argument(
     "task_id_or_name", help="ID or name of task to delete", type=str
@@ -319,7 +416,9 @@ task_delete_parser.add_argument(
 # WORKFLOW GROUP
 
 workflow_parser = subparsers_main.add_parser(
-    "workflow", description="Workflow commands"
+    "workflow",
+    description="Workflow commands",
+    allow_abbrev=False,
 )
 workflow_subparsers = workflow_parser.add_subparsers(
     title="Valid subcommand", dest="subcmd", required=True
@@ -327,7 +426,9 @@ workflow_subparsers = workflow_parser.add_subparsers(
 
 # workflow list
 workflow_list_parser = workflow_subparsers.add_parser(
-    "list", description="List workflows for given project"
+    "list",
+    description="List workflows for given project",
+    allow_abbrev=False,
 )
 workflow_list_parser.add_argument(
     "project_id",
@@ -336,7 +437,9 @@ workflow_list_parser.add_argument(
 
 # workflow new
 workflow_new_parser = workflow_subparsers.add_parser(
-    "new", description="Create new workflow"
+    "new",
+    description="Create new workflow",
+    allow_abbrev=False,
 )
 workflow_new_parser.add_argument(
     "name",
@@ -349,7 +452,9 @@ workflow_new_parser.add_argument(
 
 # workflow show
 workflow_new_parser = workflow_subparsers.add_parser(
-    "show", description="Show workflow"
+    "show",
+    description="Show workflow",
+    allow_abbrev=False,
 )
 workflow_new_parser.add_argument(
     "workflow_id",
@@ -358,7 +463,10 @@ workflow_new_parser.add_argument(
 
 # workflow edit
 workflow_edit_parser = workflow_subparsers.add_parser(
-    "edit", description="Edit workflow", argument_default=ap.SUPPRESS
+    "edit",
+    description="Edit workflow",
+    argument_default=ap.SUPPRESS,
+    allow_abbrev=False,
 )
 workflow_edit_parser.add_argument(
     "workflow_id",
@@ -369,7 +477,9 @@ workflow_edit_parser.add_argument("--name", type=str, help="New workflow name")
 
 # workflow delete
 workflow_delete_parser = workflow_subparsers.add_parser(
-    "delete", description="Delete workflow"
+    "delete",
+    description="Delete workflow",
+    allow_abbrev=False,
 )
 workflow_delete_parser.add_argument(
     "workflow_id",
@@ -379,7 +489,9 @@ workflow_delete_parser.add_argument(
 
 # workflow add task
 workflow_add_task_parser = workflow_subparsers.add_parser(
-    "add-task", description="Add new task to specific workflow"
+    "add-task",
+    description="Add new task to specific workflow",
+    allow_abbrev=False,
 )
 workflow_add_task_parser.add_argument(
     "workflow_id",
@@ -395,20 +507,22 @@ workflow_add_task_parser.add_argument(
     "--args-file",
     help=(
         "Path to json serialised file containing the arguments "
-        "ovverrides of the task"
+        "overrides of the task"
     ),
 )
 workflow_add_task_parser.add_argument(
     "--meta-file",
     help=(
-        "Path to json serialised file containing the meta"
-        "ovverrides of the task"
+        "Path to json serialised file containing the meta "
+        "overrides of the task"
     ),
 )
 
 # workflow edit task
 workflow_edit_task_parser = workflow_subparsers.add_parser(
-    "edit-task", description="Edit task within specific workflow"
+    "edit-task",
+    description="Edit task within specific workflow",
+    allow_abbrev=False,
 )
 workflow_edit_task_parser.add_argument(
     "workflow_id",
@@ -422,20 +536,22 @@ workflow_edit_task_parser.add_argument(
     "--args-file",
     help=(
         "Path to json serialised file containing the arguments "
-        "ovverrides of the task"
+        "overrides of the task"
     ),
 )
 workflow_edit_task_parser.add_argument(
     "--meta-file",
     help=(
         "Path to json serialised file containing the meta "
-        "ovverrides of the task"
+        "overrides of the task"
     ),
 )
 
 # workflow remove task
 workflow_remove_task_parser = workflow_subparsers.add_parser(
-    "rm-task", description="Remove task from a specific workflow"
+    "rm-task",
+    description="Remove task from a specific workflow",
+    allow_abbrev=False,
 )
 workflow_remove_task_parser.add_argument(
     "workflow_id",
@@ -451,6 +567,7 @@ workflow_apply_parser = workflow_subparsers.add_parser(
     "apply",
     description="Apply workflow to dataset",
     argument_default=ap.SUPPRESS,
+    allow_abbrev=False,
 )
 workflow_apply_parser.add_argument("workflow_id")
 workflow_apply_parser.add_argument("input_dataset_id")
@@ -478,6 +595,7 @@ workflow_apply_parser.add_argument(
 workflow_import_parser = workflow_subparsers.add_parser(
     "import",
     description="Import workflow to project from file",
+    allow_abbrev=False,
 )
 workflow_import_parser.add_argument(
     "--project-id",
@@ -493,6 +611,7 @@ workflow_import_parser.add_argument(
 workflow_export_parser = workflow_subparsers.add_parser(
     "export",
     description="Export workflow to file",
+    allow_abbrev=False,
 )
 workflow_export_parser.add_argument(
     "workflow_id",
@@ -506,14 +625,20 @@ workflow_export_parser.add_argument(
 
 # JOB GROUP
 
-job_parser = subparsers_main.add_parser("job", description="Job commands")
+job_parser = subparsers_main.add_parser(
+    "job",
+    description="Job commands",
+    allow_abbrev=False,
+)
 job_subparsers = job_parser.add_subparsers(
     title="Valid subcommand", dest="subcmd", required=True
 )
 
 # job list
 job_list_parser = job_subparsers.add_parser(
-    "list", description="List jobs for given project"
+    "list",
+    description="List jobs for given project",
+    allow_abbrev=False,
 )
 job_list_parser.add_argument(
     "project_id",
@@ -525,6 +650,7 @@ job_show_parser = job_subparsers.add_parser(
     "show",
     description="Query status of workflow-execution job",
     argument_default=ap.SUPPRESS,
+    allow_abbrev=False,
 )
 job_show_parser.add_argument(
     "job_id",
@@ -542,6 +668,7 @@ job_show_parser.add_argument(
 job_download_logs_parser = job_subparsers.add_parser(
     "download-logs",
     description="Download full folder of workflow-execution job",
+    allow_abbrev=False,
 )
 job_download_logs_parser.add_argument(
     "job_id",
@@ -557,7 +684,9 @@ job_download_logs_parser.add_argument(
 
 # VERSION GROUP
 version_parser = subparsers_main.add_parser(
-    "version", description="Print version and exit"
+    "version",
+    description="Print version and exit",
+    allow_abbrev=False,
 )
 
 
@@ -566,6 +695,7 @@ version_parser = subparsers_main.add_parser(
 user_parser = subparsers_main.add_parser(
     "user",
     description="User commands",
+    allow_abbrev=False,
 )
 user_subparsers = user_parser.add_subparsers(
     title="Valid subcommand", dest="subcmd", required=True
@@ -575,11 +705,14 @@ user_subparsers = user_parser.add_subparsers(
 user_whoami_parser = user_subparsers.add_parser(
     "whoami",
     description="Get info on current user (fails if user is not registered)",
+    allow_abbrev=False,
 )
 
 # user register
 user_register_parser = user_subparsers.add_parser(
-    "register", description="Register a new user with the Fractal server"
+    "register",
+    description="Register a new user with the Fractal server",
+    allow_abbrev=False,
 )
 user_register_parser.add_argument(
     "new_email", help="Email to be used as username"
@@ -603,17 +736,22 @@ user_register_parser.add_argument(
 user_list_parser = user_subparsers.add_parser(
     "list",
     description="List all users",
+    allow_abbrev=False,
 )
 
 # user show
 user_show_parser = user_subparsers.add_parser(
-    "show", description="Show details of single user"
+    "show",
+    description="Show details of single user",
+    allow_abbrev=False,
 )
 user_show_parser.add_argument("user_id", help="ID of the user")
 
 # user edit
 user_edit_parser = user_subparsers.add_parser(
-    "edit", description="Edit details of single user"
+    "edit",
+    description="Edit details of single user",
+    allow_abbrev=False,
 )
 user_edit_parser.add_argument("user_id", help="ID of the user")
 user_edit_parser.add_argument(
@@ -642,6 +780,8 @@ user_edit_parser_superuser.add_argument(
 
 # user delete
 user_delete_parser = user_subparsers.add_parser(
-    "delete", description="Delete a single user"
+    "delete",
+    description="Delete a single user",
+    allow_abbrev=False,
 )
 user_delete_parser.add_argument("user_id", help="ID of the user")
